@@ -57,6 +57,8 @@ function create_ovs_manager_user {
         echo "#includedir /etc/sudoers.d" | sudo tee -a /etc/sudoers
     ( umask 226 && echo "$GENERIC_SWITCH_USER ALL=(ALL) NOPASSWD:ALL" | sudo tee /etc/sudoers.d/99_ngs_ovs_manager )
 
+    # Hush the login banner for ovs user
+    touch $GENERIC_SWITCH_USER_HOME/.hushlogin
 }
 
 function configure_for_dlm {
@@ -114,6 +116,9 @@ function configure_generic_switch {
     fi
     populate_ml2_config /$Q_PLUGIN_CONF_FILE ml2 mechanism_drivers=$Q_ML2_PLUGIN_MECHANISM_DRIVERS
 
+    # set netmiko session log
+    populate_ml2_config $GENERIC_SWITCH_INI_FILE ngs session_log_file=$GENERIC_SWITCH_DATA_DIR/netmiko_session.log
+
     # Generate SSH keypair
     configure_generic_switch_user
 
@@ -133,7 +138,7 @@ function configure_generic_switch {
         local bridge_mac
         bridge_mac=$(ip link show dev $switch | egrep -o "ether [A-Za-z0-9:]+"|sed "s/ether\ //")
         switch="genericswitch:$switch"
-        add_generic_switch_to_ml2_config $switch $GENERIC_SWITCH_KEY_FILE $GENERIC_SWITCH_USER localhost netmiko_ovs_linux "$GENERIC_SWITCH_PORT" "$bridge_mac"
+        add_generic_switch_to_ml2_config $switch $GENERIC_SWITCH_KEY_FILE $GENERIC_SWITCH_USER ::1 netmiko_ovs_linux "$GENERIC_SWITCH_PORT" "$bridge_mac"
     done
     echo "HOST_TOPOLOGY: $HOST_TOPOLOGY"
     echo "HOST_TOPOLOGY_SUBNODES: $HOST_TOPOLOGY_SUBNODES"
