@@ -14,13 +14,13 @@
 
 import atexit
 import contextlib
+import functools
 import uuid
 
 import netmiko
 from oslo_config import cfg
 from oslo_log import log as logging
 import paramiko
-import six
 import tenacity
 from tooz import coordination
 
@@ -42,7 +42,7 @@ def check_output(operation):
     def decorator(func):
         """The real decorator."""
 
-        @six.wraps(func)
+        @functools.wraps(func)
         def wrapper(self, *args, **kwargs):
             """Wrapper that checks the output of an operation.
 
@@ -95,6 +95,10 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
             raise exc.GenericSwitchNetmikoNotSupported(
                 device_type=device_type)
         self.config['device_type'] = device_type
+        if CONF.ngs.session_log_file:
+            self.config['session_log'] = CONF.ngs.session_log_file
+            self.config['session_log_record_writes'] = True
+            self.config['session_log_file_mode'] = 'append'
 
         self.locker = None
         if CONF.ngs_coordination.backend_url:
@@ -194,9 +198,13 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
         # NOTE(zhenguo): Remove dashes from uuid as on most devices 32 chars
         # is the max length of vlan name.
         network_id = uuid.UUID(network_id).hex
+        network_name = self._get_network_name(network_id, segmentation_id)
+        # NOTE(mgoddard): Pass network_id and segmentation_id for drivers not
+        # yet using network_name.
         cmds = self._format_commands(self.ADD_NETWORK,
                                      segmentation_id=segmentation_id,
-                                     network_id=network_id)
+                                     network_id=network_id,
+                                     network_name=network_name)
         for port in self._get_trunk_ports():
             cmds += self._format_commands(self.ADD_NETWORK_TO_TRUNK,
                                           port=port,
@@ -213,9 +221,13 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
             cmds += self._format_commands(self.REMOVE_NETWORK_FROM_TRUNK,
                                           port=port,
                                           segmentation_id=segmentation_id)
+        network_name = self._get_network_name(network_id, segmentation_id)
+        # NOTE(mgoddard): Pass network_id and segmentation_id for drivers not
+        # yet using network_name.
         cmds += self._format_commands(self.DELETE_NETWORK,
                                       segmentation_id=segmentation_id,
-                                      network_id=network_id)
+                                      network_id=network_id,
+                                      network_name=network_name)
         return self.send_commands_to_device(cmds)
 
     @check_output('plug port')
@@ -242,10 +254,15 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
                                      segmentation_id=segmentation_id)
         ngs_port_default_vlan = self._get_port_default_vlan()
         if ngs_port_default_vlan:
+            # NOTE(mgoddard): Pass network_id and segmentation_id for drivers
+            # not yet using network_name.
+            network_name = self._get_network_name(ngs_port_default_vlan,
+                                                  ngs_port_default_vlan)
             cmds += self._format_commands(
                 self.ADD_NETWORK,
                 segmentation_id=ngs_port_default_vlan,
-                network_id=ngs_port_default_vlan)
+                network_id=ngs_port_default_vlan,
+                network_name=network_name)
             cmds += self._format_commands(
                 self.PLUG_PORT_TO_NETWORK,
                 port=port,
@@ -262,7 +279,8 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
         :returns: The output of the configuration commands.
         """
         net_connect.enable()
-        return net_connect.send_config_set(config_commands=cmd_set)
+        return net_connect.send_config_set(config_commands=cmd_set,
+                                           cmd_verify=False)
 
     def save_configuration(self, net_connect):
         """Try to save the device's configuration.
