@@ -19,7 +19,6 @@ from neutron_lib.api.definitions import portbindings
 from neutron_lib.callbacks import resources
 from neutron_lib.plugins.ml2 import api
 from oslo_log import log as logging
-import six
 
 from networking_generic_switch import config as gsw_conf
 from networking_generic_switch import devices
@@ -53,7 +52,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Allocate resources for a new network.
 
         :param context: NetworkContext instance describing the new
-        network.
+            network.
 
         Create a new network, allocating resources as necessary in the
         database. Called inside transaction context on session. Call
@@ -66,7 +65,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Create a network.
 
         :param context: NetworkContext instance describing the new
-        network.
+            network.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -101,8 +100,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update resources of a network.
 
         :param context: NetworkContext instance describing the new
-        state of the network, as well as the original state prior
-        to the update_network call.
+             state of the network, as well as the original state prior
+             to the update_network call.
 
         Update values of a network, updating the associated resources
         in the database. Called inside transaction context on session.
@@ -112,6 +111,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         update_network_precommit is called for all changes to the
         network state. It is up to the mechanism driver to ignore
         state or state changes that it does not know or care about.
+
         """
         pass
 
@@ -119,8 +119,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update a network.
 
         :param context: NetworkContext instance describing the new
-        state of the network, as well as the original state prior
-        to the update_network call.
+            state of the network, as well as the original state prior
+            to the update_network call.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -137,7 +137,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete resources for a network.
 
         :param context: NetworkContext instance describing the current
-        state of the network, prior to the call to delete it.
+            state of the network, prior to the call to delete it.
 
         Delete network resources previously allocated by this
         mechanism driver for a network. Called inside transaction
@@ -151,7 +151,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete a network.
 
         :param context: NetworkContext instance describing the current
-        state of the network, prior to the call to delete it.
+            state of the network, prior to the call to delete it.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -183,13 +183,14 @@ class GenericSwitchDriver(api.MechanismDriver):
                              '%(device)s', {'net_id': network['id'],
                                             'device': switch_name})
             if exc_info:
-                six.reraise(*exc_info)
+                raise exc_info[1]
 
     def create_subnet_precommit(self, context):
         """Allocate resources for a new subnet.
 
         :param context: SubnetContext instance describing the new
-        subnet.
+            subnet.
+
         rt = context.current
         device_id = port['device_id']
         device_owner = port['device_owner']
@@ -204,7 +205,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Create a subnet.
 
         :param context: SubnetContext instance describing the new
-        subnet.
+            subnet.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -217,8 +218,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update resources of a subnet.
 
         :param context: SubnetContext instance describing the new
-        state of the subnet, as well as the original state prior
-        to the update_subnet call.
+            state of the subnet, as well as the original state prior
+            to the update_subnet call.
 
         Update values of a subnet, updating the associated resources
         in the database. Called inside transaction context on session.
@@ -235,8 +236,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update a subnet.
 
         :param context: SubnetContext instance describing the new
-        state of the subnet, as well as the original state prior
-        to the update_subnet call.
+            state of the subnet, as well as the original state prior
+            to the update_subnet call.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -253,7 +254,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete resources for a subnet.
 
         :param context: SubnetContext instance describing the current
-        state of the subnet, prior to the call to delete it.
+            state of the subnet, prior to the call to delete it.
 
         Delete subnet resources previously allocated by this
         mechanism driver for a subnet. Called inside transaction
@@ -267,7 +268,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete a subnet.
 
         :param context: SubnetContext instance describing the current
-        state of the subnet, prior to the call to delete it.
+            state of the subnet, prior to the call to delete it.
 
         Called after the transaction commits. Call can block, though
         will block the entire process so care should be taken to not
@@ -305,8 +306,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update resources of a port.
 
         :param context: PortContext instance describing the new
-        state of the port, as well as the original state prior
-        to the update_port call.
+            state of the port, as well as the original state prior
+            to the update_port call.
 
         Called inside transaction context on session to complete a
         port update as defined by this mechanism driver. Raising an
@@ -322,8 +323,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Update a port.
 
         :param context: PortContext instance describing the new
-        state of the port, as well as the original state prior
-        to the update_port call.
+            state of the port, as well as the original state prior
+            to the update_port call.
 
         Called after the transaction completes. Call can block, though
         will block the entire process so care should be taken to not
@@ -362,7 +363,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete resources of a port.
 
         :param context: PortContext instance describing the current
-        state of the port, prior to the call to delete it.
+            state of the port, prior to the call to delete it.
 
         Called inside transaction context on session. Runtime errors
         are not expected, but raising an exception will result in
@@ -374,7 +375,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         """Delete a port.
 
         :param context: PortContext instance describing the current
-        state of the port, prior to the call to delete it.
+            state of the port, prior to the call to delete it.
 
         Called after the transaction completes. Call can block, though
         will block the entire process so care should be taken to not
